/****************************************************************************
 * (c) 2018 softwareentwicklung-als-prozess.de
 * Dokumentation s. Blog
 * Funktionalitaet:
 * Messwerte auf LCD Display ausgeben
 ***************************************************************************/
// Includes -----------------------------------------------------------------
#include <Wire.h>
#include <LiquidCrystal_I2C.h>

#include "lcd.h"
#include "globals.h"

// Variablen -----------------------------------------------------------------
LiquidCrystal_I2C lcd(0x27, 2, 1, 0, 4, 5, 6, 7, 3, POSITIVE);

// Funktionen ----------------------------------------------------------------
void LCD_Startup(void)
{
  lcd.begin(20,4);
  lcd.clear();
  lcd.setCursor(0,0);
  lcd.print(F("+------------------+"));
  lcd.setCursor(0,1);
  lcd.print(F("|      SEaP:       |"));
  lcd.setCursor(0,2);
  lcd.print(F("|                  |"));
  lcd.setCursor(0,3);
  lcd.print(F("+------------------+"));  
  delay(2000);
}

void LCD_ShowValues(void)
{
  char grad[2] = {(char)223,(char)0}; // Gradzeichen nach Datenblatt LCD 44780

  lcd.clear();
  lcd.setCursor(0,0);
  lcd.print(F("Temperatur  = "));
  lcd.print(Get_Temperatur());
  lcd.print(grad);
  lcd.print(F("C"));
  lcd.setCursor(0,1);
  lcd.print(F("Luftfeuchte = "));
  lcd.print(Get_Humidity());
  lcd.print(F("%"));
  lcd.setCursor(0,2);
  lcd.print(F("Datum   : "));
  lcd.print(Get_Datum());
  lcd.setCursor(0,3);
  lcd.print(F("Uhrzeit : "));
  lcd.print(Get_Zeit());
}

void LCD_ShowFehler(char fno)
{
  lcd.clear();
  lcd.setCursor(0,0);
  lcd.print(F("Fehler:"));
  switch(fno)
  {
    case ERR_OK :
      lcd.setCursor(0,0);
      lcd.print(F("Ethernet Verbunden!"));
      lcd.setCursor(0,1);
      lcd.print(F("Alles Gut"));
      lcd.setCursor(0,2);
      lcd.print(F(":-):-):-)"));
      break;
    case ERR_NODHCP :
      lcd.setCursor(0,1);
      lcd.print(F("kein DHCP!"));
      lcd.setCursor(0,2);
      lcd.print(F("Netzwerk ?"));
      break;
    case ERR_ETH :
      lcd.setCursor(0,1);
      lcd.print(F("Ethernet!"));
      lcd.setCursor(0,2);
      lcd.print(F("Controller Init"));
      break;
    case ERR_MQTT :
      lcd.setCursor(0,1);
      lcd.print(F("MQTT Server!"));
      lcd.setCursor(0,2);
      lcd.print(F("keine verbindung ..."));
      lcd.setCursor(0,3);
      lcd.print(F("Wiederhole in 10 Sek"));
      break;
    default:
      lcd.setCursor(0,1);
      lcd.print(F("unbekannt!"));
      lcd.setCursor(0,2);
      lcd.print(F("??????????"));
      break;
  }
  delay(5000);
}

