/****************************************************************************
 * (c) 2018 softwareentwicklung-als-prozess.de
 * Dokumentation s. Blog
 * Funktionalitaet:
 * Messwerte als MP3 auf Lautsprecher ausgeben
 ***************************************************************************/
// Includes -----------------------------------------------------------------
#include <SoftwareSerial.h>
#include <DFMiniMp3.h>
#include <arduino.h>

#include "mp3.h"
#include "globals.h"

// Defines -----------------------------------------------------------------
#define ASCII_OFFSET (char)48 // Die ASCII 0 hat den Wert 48
// Die Nummern fuer die MP3 Dateinamen in lesbarer Form
#define MP3_EIN 1
#define MP3_EINS 2
#define MP3_ZWEI 3
#define MP3_DREI 4
#define MP3_VIER 5
#define MP3_FUENF 6
#define MP3_SECHS 7
#define MP3_SIEBEN 8
#define MP3_SIEB 9
#define MP3_ACHT 10
#define MP3_NEUN 11
#define MP3_ZEHN 12
#define MP3_ELF 13
#define MP3_ZWOELF 14
#define MP3_UND 15
#define MP3_ZWANZIG 16
#define MP3_DREISSIG 17
#define MP3_VIERZIG 18
#define MP3_FUENFZIG 19
#define MP3_SECHZIG 20
#define MP3_SIEBZIG 21
#define MP3_ACHTZIG 22
#define MP3_NEUNZIG 23

// Klassen -----------------------------------------------------------------
class Mp3Notify
{
public:
  static void OnError(uint16_t errorCode)
  {
    // see DfMp3_Error for code meaning
    Serial.println();
    Serial.print(F("Com Error "));
    Serial.println(errorCode);
  }

  static void OnPlayFinished(uint16_t globalTrack)
  {
    Serial.println();
    Serial.print(F("Play finished for #"));
    Serial.println(globalTrack);   
  }

  static void OnCardOnline(uint16_t code)
  {
    Serial.println();
    Serial.print(F("Card online "));
    Serial.println(code);     
  }

  static void OnCardInserted(uint16_t code)
  {
    Serial.println();
    Serial.print(F("Card inserted "));
    Serial.println(code); 
  }

  static void OnCardRemoved(uint16_t code)
  {
    Serial.println();
    Serial.print(F("Card removed "));
    Serial.println(code);  
  }
};

// Variablen -----------------------------------------------------------------
// instance a DFMiniMp3 object, 
// defined with the above notification class and the software serial class
SoftwareSerial secondarySerial(3, 2); // RX, TX
DFMiniMp3<SoftwareSerial, Mp3Notify> mp3(secondarySerial);

// Funktionen ----------------------------------------------------------------
void MP3_Startup(void)
{
  mp3.begin();
  mp3.setVolume(25);
}

void waitMilliseconds(uint16_t msWait)
{
  uint32_t start = millis();
  
  while ((millis() - start) < msWait)
  {
    // calling mp3.loop() periodically allows for notifications 
    // to be handled without interrupts
    mp3.loop(); 
    delay(1);
  }
}

void MP3_SagZahl(char einer, char zehner)
{
  switch(einer - ASCII_OFFSET) // ASCII in int umrechnen
  {
    case 0:
      break;
    case 1:
      if ((zehner - ASCII_OFFSET) == (char)1)
      {
        mp3.playMp3FolderTrack(MP3_ELF);
        waitMilliseconds(1000);
      }
      else
      {
        mp3.playMp3FolderTrack(MP3_EIN);
        waitMilliseconds(1000);
      }
      break;
    case 2:
      if ((zehner - ASCII_OFFSET) == (char)1)
      {
        mp3.playMp3FolderTrack(MP3_ZWOELF);
        waitMilliseconds(1000);
      }
      else
      {
        mp3.playMp3FolderTrack(MP3_ZWEI);
        waitMilliseconds(1000);
      }
      break;
    case 3:
      mp3.playMp3FolderTrack(MP3_DREI);
      waitMilliseconds(1000);
      break;
    case 4:
      mp3.playMp3FolderTrack(MP3_VIER);
      waitMilliseconds(1000);
      break;
    case 5:
      mp3.playMp3FolderTrack(MP3_FUENF);
      waitMilliseconds(1000);
      break;
    case 6:
      mp3.playMp3FolderTrack(MP3_SECHS);
      waitMilliseconds(1000);
      break;
    case 7:
      if ((zehner - ASCII_OFFSET) == (char)1)
      {
        mp3.playMp3FolderTrack(MP3_SIEB);
        waitMilliseconds(300);
      }
      else
        mp3.playMp3FolderTrack(MP3_SIEBEN);
        waitMilliseconds(1000);
      break;
    case 8:
      mp3.playMp3FolderTrack(MP3_ACHT);
      waitMilliseconds(1000);
      break;
    case 9:
      mp3.playMp3FolderTrack(MP3_NEUN);
      waitMilliseconds(1000);
      break;   
  }
  switch(zehner - ASCII_OFFSET)
  {
    case 0:
      break;
    case 1:
      if (((einer - ASCII_OFFSET) == (char)1) || ((einer - ASCII_OFFSET) == (char)2)) // 11 und 12 s. oben
      {
      }
      else
      {
        mp3.playMp3FolderTrack(MP3_ZEHN);
        waitMilliseconds(1000);
      }
      break;
    case 2:
      if((einer - ASCII_OFFSET) > (char)0)
      {
        mp3.playMp3FolderTrack(MP3_UND);
        waitMilliseconds(1000);
      }
      mp3.playMp3FolderTrack(MP3_ZWANZIG);
      waitMilliseconds(1000);
      break;
    case 3:
      if((einer - ASCII_OFFSET) > (char)0)
      {
        mp3.playMp3FolderTrack(MP3_UND);
        waitMilliseconds(1000);
      }
      mp3.playMp3FolderTrack(MP3_DREISSIG);
      waitMilliseconds(1000);
      break;
    case 4:
      if((einer - ASCII_OFFSET) > (char)0)
      {
        mp3.playMp3FolderTrack(MP3_UND);
        waitMilliseconds(1000);
      }
      mp3.playMp3FolderTrack(MP3_VIERZIG);
      waitMilliseconds(1000);
      break;
    case 5:
      if((einer - ASCII_OFFSET) > (char)0)
      {
        mp3.playMp3FolderTrack(MP3_UND);
        waitMilliseconds(1000);
      }
      mp3.playMp3FolderTrack(MP3_FUENFZIG);
      waitMilliseconds(1000);
      break;
    case 6:
      if((einer - ASCII_OFFSET) > (char)0)
      {
        mp3.playMp3FolderTrack(MP3_UND);
        waitMilliseconds(1000);
      }
      mp3.playMp3FolderTrack(MP3_SECHZIG);
      waitMilliseconds(1000);
      break;
    case 7:
      if((einer - ASCII_OFFSET) > (char)0)
      {
        mp3.playMp3FolderTrack(MP3_UND);
        waitMilliseconds(1000);
      }
      mp3.playMp3FolderTrack(MP3_SIEBZIG);
      waitMilliseconds(1000);
      break;
    case 8:
      if((einer - ASCII_OFFSET) > (char)0)
      {
        mp3.playMp3FolderTrack(MP3_UND);
        waitMilliseconds(1000);
      }
      mp3.playMp3FolderTrack(MP3_ACHTZIG);
      waitMilliseconds(1000);
      break;
    case 9:
      if((einer - ASCII_OFFSET) > (char)0)
      {
        mp3.playMp3FolderTrack(MP3_UND);
        waitMilliseconds(1000);
      }
      mp3.playMp3FolderTrack(MP3_NEUNZIG);
      waitMilliseconds(1000);
      break;   
  }
}

void MP3_SagEsLaut(void) // Messwerte ansagen
{
  char *temp;
  char zehner;
  char einer;

  mp3.playMp3FolderTrack(24); // Die zuletzt eingelesenen Werte
  waitMilliseconds(2000);
  mp3.playMp3FolderTrack(25); // Die Temperatur betraegt
  waitMilliseconds(2000);
  mp3.playMp3FolderTrack(26); // plus
  waitMilliseconds(1000);
  temp = Get_Temperatur();
  zehner = temp[0];
  einer  = temp[1];
  MP3_SagZahl(einer, zehner); // Messwert
  mp3.playMp3FolderTrack(28); // Grad Celsius
  waitMilliseconds(2000);
  mp3.playMp3FolderTrack(29); // Die relative Luftfeuchtigkeit betraegt
  waitMilliseconds(3000);
  temp = Get_Humidity();
  zehner = temp[0];
  einer  = temp[1];
  MP3_SagZahl(einer, zehner); // Messwert
  mp3.playMp3FolderTrack(30); // Prozent
  waitMilliseconds(2000);
}

