/****************************************************************************
 * (c) 2018 softwareentwicklung-als-prozess.de
 * Dokumentation s. Blog
 * Funktionalitaet:
 * Messwerte ueber MQTT einlesen
 ***************************************************************************/
// Includes -----------------------------------------------------------------
#include <SPI.h>
#include <Ethernet2.h>
#include <PubSubClient.h>

#include "globals.h"
#include "mqtt.h"
#include "lcd.h"

// Variablen -----------------------------------------------------------------
const char top1[] = "Wohnung/Raum1/Temperatur/Messwert";
const char top2[] = "Wohnung/Raum1/Temperatur/Messzeit";
const char top3[] = "Wohnung/Raum1/Luftfeuchte/Messwert";
const char top4[] = "Wohnung/Raum1/Luftfeuchte/Messzeit";
bool neuerwert = false;
bool tp1 = false;
bool tp2 = false;
bool tp3 = false;
bool tp4 = false;

// Ethernet
byte mac[] = { 0x12,0x34,0x56,0x78,0x9A,0xBE };
EthernetClient client;

// PubSubClient
IPAddress    pscsrv(192, 168, 198, 26);
unsigned int pscport = 1883;
PubSubClient pscclient(client);

// interne Funktionen
void MQTTCallback(char* topic, byte* payload, unsigned int length);
void MQTTReconnect();

// Funktionen ----------------------------------------------------------------
void MQTT_Startup(void)
{
  pscclient.setServer(pscsrv, pscport);
  pscclient.setCallback(MQTTCallback);

  if (Ethernet.begin(mac) == 0)
  {
    LCD_ShowFehler(ERR_ETH);
    delay(10000);
  }
  else
  {
    LCD_ShowFehler(ERR_OK);
    LCD_ShowValues();  // Maske mit Initwerten anzeigen
  }
}

void MQTT_Connect(void)
{
  if (!pscclient.connected()) 
  {
    MQTTReconnect();
  }
  pscclient.loop();
}

bool MQTT_GetReceived(void)
{
  return(neuerwert);  
}

void MQTT_ResetReceived(void)
{
  neuerwert = false;
}

void MQTTReconnect() 
{
  // Loop until we're reconnected
  while (!pscclient.connected()) 
  {
    if (pscclient.connect("JGE-Sub")) 
    {
      pscclient.subscribe(top1);
      pscclient.subscribe(top2);
      pscclient.subscribe(top3);
      pscclient.subscribe(top4);
    } 
    else 
    {
      LCD_ShowFehler(ERR_MQTT);
      delay(5000);
    }
  }
}

void MQTTCallback(char* topic, byte* payload, unsigned int length) 
{
  int i = 0;
  
  if (strcmp(topic,top1) == 0)
  {
    Set_Temperatur(payload);
    tp1 = true;
  }
  if (strcmp(topic,top2) == 0)
  {
    Set_Datum(payload);
    Set_Zeit(payload);
    tp2 = true;
  }
  if (strcmp(topic,top3) == 0)
  {
    Set_Humidity(payload);
    tp3 = true;
  }  
  if (strcmp(topic,top4) == 0)
  {
    Set_Datum(payload);
    Set_Zeit(payload);
    tp4 = true;
  }
  if ((true == tp1) && (true == tp2) && (true == tp3) && (true == tp4))
  {
    tp1 = tp2 = tp3 = tp4 = false;
    neuerwert = true;
  }
}

